==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/sdk/actions/application/CloseAllAction.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef CLOSEALLACTION_H
#define CLOSEALLACTION_H

#include <QObject>
#include <Action.h>
#include <Component.h>

class CloseAllAction : public camitk::Action {

public:
  /// Default Constructor
  CloseAllAction(camitk::ActionExtension *);

  /// Default Destructor
  virtual ~CloseAllAction();

  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
  virtual QWidget * getWidget();

public slots:
  /** this method is automatically called when the action is triggered.
    * It gets all the targets' top level component and close them.
    */
  virtual ApplyStatus apply();

};
#endif // CLOSEALLACTION_H

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/actions/application/CloseAllAction.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef CLOSEALLACTION_H
#define CLOSEALLACTION_H

#include <QObject>
#include <Action.h>
#include <Component.h>

/**
 * @ingroup group_sdk_actions_application
 * 
 * @brief 
 * The CloseAllAction class allows to close all selected component in the current application.
 * 
 **/
class CloseAllAction : public camitk::Action {

public:
  /// Default Constructor
  CloseAllAction(camitk::ActionExtension *);

  /// Default Destructor
  virtual ~CloseAllAction();

  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
  virtual QWidget * getWidget();

public slots:
  /** this method is automatically called when the action is triggered.
    * It gets all the targets' top level component and close them.
    */
  virtual ApplyStatus apply();

};
#endif // CLOSEALLACTION_H
